===============
Sentry-Campfire
===============

A Sentry plugin that allows notifications to be sent to Campfire


Installation
============

To install and use this plugin just install it via `pip`::

  pip install sentry_campfire

This is all that's needed. You can configure the plugin from web UI.
